.. _spider_ak.ciando.com:

ak.ciando.com
-------------
Most recently added books to the Arbeiterkammer e-library on `ak.ciando.com <https://ak.ciando.com>`_.

Configuration
~~~~~~~~~~~~~
Add ``ak.ciando.com`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     ak.ciando.com

